==> RMassBank_1.2.1.zip: RMassBank/doc/RMassBank.R <==
### R code from vignette source 'RMassBank.Rnw'

###################################################
### code chunk number 1: RMassBank.Rnw:24-26
###################################################
options(width=74)
#library(xtable)


###################################################
### code chunk number 2: RMassBank.Rnw:68-69
###################################################
library(RMassBank)


###################################################
### code chunk number 3: RMassBank.Rnw:75-76
###################################################
library(RMassBankData)


###################################################
### code chunk number 4: RMassBank.Rnw:128-130
###################################################
file.copy(system.file("list/NarcoticsDataset.csv", 
	package="RMassBankData"), "./Compoundlist.csv")


###################################################
### code chunk number 5: RMassBank.Rnw:139-140
###################################################
RmbSettingsTemplate("mysettings.ini")


###################################################
### code chunk number 6: RMassBank.Rnw:218-219
###################################################
loadRmbSettings("mysettings.ini")


###################################################
### code chunk number 7: RMassBank.Rnw:231-232
###################################################
w <- newMsmsWorkspace()


###################################################
### code chunk number 8: RMassBank.Rnw:238-243
###################################################
files <- list.files(system.file("spectra", package="RMassBankData"),
	 ".mzML", full.names = TRUE)
basename(files)
# To make the workflow faster here, we use only 2 compounds:
w@files <- files[1:2]


###################################################
### code chunk number 9: RMassBank.Rnw:251-252
###################################################
loadList("./Compoundlist.csv")


###################################################
### code chunk number 10: RMassBank.Rnw:297-299
###################################################
w <- msmsWorkflow(w, mode="pH", steps=c(1:4), archivename = 
				"pH_narcotics")


###################################################
### code chunk number 11: RMassBank.Rnw:307-311 (eval = FALSE)
###################################################
## 	w <- msmsWorkflow(w, mode="pH", steps=1)
## 	w <- msmsWorkflow(w, mode="pH", steps=2)
## 	w <- msmsWorkflow(w, mode="pH", steps=3)
## 	# etc.


###################################################
### code chunk number 12: RMassBank.Rnw:320-325
###################################################
# In the really evaluated workflow, we do the following:
# we run steps 1 through 3, load the recalibration curve from a stored workflow
# and recalibrate the data using that curve.
storedW <- loadMsmsWorkspace(system.file("results/pH_narcotics_RF.RData", 
				package="RMassBankData"))


###################################################
### code chunk number 13: RMassBank.Rnw:331-340
###################################################
# Just to display the recalibration curve as calculated from
# the complete dataset:
storedW <- msmsWorkflow(storedW, mode="pH", steps=4)
# Copy the recalibration to workspace w and apply it
# (no graph displayed here)
w@rc <- storedW@rc
w@rc.ms1 <- storedW@rc.ms1
w <- msmsWorkflow(w, mode="pH", steps=4, archivename = 
	"pH_narcotics", newRecalibration = FALSE)


###################################################
### code chunk number 14: RMassBank.Rnw:345-347
###################################################
w <- msmsWorkflow(w, mode="pH", steps=c(5:8), archivename = 
		"pH_narcotics")


###################################################
### code chunk number 15: RMassBank.Rnw:352-353 (eval = FALSE)
###################################################
## archiveResults(w, filename)


###################################################
### code chunk number 16: RMassBank.Rnw:379-383
###################################################
mb <- newMbWorkspace(w)
mb <- resetInfolists(mb)
mb <- loadInfolists(mb, system.file("infolists_incomplete",
		package="RMassBankData"))


###################################################
### code chunk number 17: RMassBank.Rnw:387-389 (eval = FALSE)
###################################################
## mb <- resetInfolists(mb)
## mb <- loadInfolists(mb, my_folder_with_csv_infolists_inside)


###################################################
### code chunk number 18: RMassBank.Rnw:393-394 (eval = FALSE)
###################################################
## mb <- addPeaks(mb, my_corrected_Failpeaks.csv)


###################################################
### code chunk number 19: RMassBank.Rnw:399-400
###################################################
mb <- mbWorkflow(mb, infolist_path="./Narcotics_infolist.csv")


###################################################
### code chunk number 20: RMassBank.Rnw:416-418 (eval = FALSE)
###################################################
## mb <- resetInfolists(mb)
## mb <- loadInfolists(mb, my_folder_with_csv_infolists_inside)


###################################################
### code chunk number 21: RMassBank.Rnw:424-426
###################################################
mb <- resetInfolists(mb)
mb <- loadInfolists(mb, system.file("infolists", package="RMassBankData"))


###################################################
### code chunk number 22: RMassBank.Rnw:432-433
###################################################
mb <- mbWorkflow(mb)


###################################################
### code chunk number 23: RMassBank.Rnw:470-471
###################################################
sessionInfo()

==> RMassBank_1.6.0.zip: RMassBank/doc/RMassBank.R <==
### R code from vignette source 'RMassBank.Rnw'

###################################################
### code chunk number 1: RMassBank.Rnw:24-26
###################################################
options(width=74)
#library(xtable)


###################################################
### code chunk number 2: RMassBank.Rnw:69-70
###################################################
library(RMassBank)


###################################################
### code chunk number 3: RMassBank.Rnw:76-77
###################################################
library(RMassBankData)


###################################################
### code chunk number 4: RMassBank.Rnw:129-131
###################################################
file.copy(system.file("list/NarcoticsDataset.csv", 
	package="RMassBankData"), "./Compoundlist.csv")


###################################################
### code chunk number 5: RMassBank.Rnw:140-141
###################################################
RmbSettingsTemplate("mysettings.ini")


###################################################
### code chunk number 6: RMassBank.Rnw:268-269
###################################################
loadRmbSettings("mysettings.ini")


###################################################
### code chunk number 7: RMassBank.Rnw:281-282
###################################################
w <- newMsmsWorkspace()


###################################################
### code chunk number 8: RMassBank.Rnw:288-303 (eval = FALSE)
###################################################
## 
## #####SCRIPT
## library(RMassBank)
## loadRmbSettings("settings_comrecal_QEx_EX.INI")
## loadList("QEx_10_compoundlist.csv")
## msmsmzR <- newMsmsWorkspace()
## msmsXCMS <- newMsmsWorkspace()
## Args <- list(method="centWave", ppm = 5, snthresh = 1.5,
##     peakwidth = c(20,60), integrate = 1, mzdiff = -0.001, mzCenterFun = "meanApex3")
## msmsmzR <- msmsRead(msmsmzR, filetable = "Filelist_QEx.csv", readMethod="mzR", mode="pH", Args=Args)
## 
## datadir <- "/vol/data_extern/emma.schymanski@ufz.de/Qexactive/10_centroided_mzMLs"
## files <- list.files(datadir, pattern=".mzML", full.names=TRUE)
## cpdid <- c(3035,2845,3040,3041,139,3046,297,3050,2856,3052)
## msmsXCMS <- msmsRead(msmsXCMS, files=files, cpdids = cpdid, readMethod="xcms",mode="pH",Args=Args)


###################################################
### code chunk number 9: RMassBank.Rnw:311-316
###################################################
files <- list.files(system.file("spectra", package="RMassBankData"),
	 ".mzML", full.names = TRUE)
basename(files)
# To make the workflow faster here, we use only 2 compounds:
w@files <- files[1:2]


###################################################
### code chunk number 10: RMassBank.Rnw:324-325
###################################################
loadList("./Compoundlist.csv")


###################################################
### code chunk number 11: RMassBank.Rnw:370-372
###################################################
w <- msmsWorkflow(w, mode="pH", steps=c(1:4), archivename = 
				"pH_narcotics")


###################################################
### code chunk number 12: RMassBank.Rnw:377-378 (eval = FALSE)
###################################################
## plotRecalibration(w)


###################################################
### code chunk number 13: RMassBank.Rnw:387-391 (eval = FALSE)
###################################################
## 	w <- msmsWorkflow(w, mode="pH", steps=1)
## 	w <- msmsWorkflow(w, mode="pH", steps=2)
## 	w <- msmsWorkflow(w, mode="pH", steps=3)
## 	# etc.


###################################################
### code chunk number 14: RMassBank.Rnw:395-396 (eval = FALSE)
###################################################
## lapply(w@specs,function(s) s$foundOK)


###################################################
### code chunk number 15: RMassBank.Rnw:400-401 (eval = FALSE)
###################################################
## findProgress(w)


###################################################
### code chunk number 16: RMassBank.Rnw:409-414
###################################################
# In the really evaluated workflow, we do the following:
# we run steps 1 through 3, load the recalibration curve from a stored workflow
# and recalibrate the data using that curve.
storedW <- loadMsmsWorkspace(system.file("results/pH_narcotics_RF.RData", 
				package="RMassBankData"))


###################################################
### code chunk number 17: RMassBank.Rnw:420-429
###################################################
# Just to display the recalibration curve as calculated from
# the complete dataset:
storedW <- msmsWorkflow(storedW, mode="pH", steps=4)
# Copy the recalibration to workspace w and apply it
# (no graph displayed here)
w@rc <- storedW@rc
w@rc.ms1 <- storedW@rc.ms1
w <- msmsWorkflow(w, mode="pH", steps=4, archivename = 
	"pH_narcotics", newRecalibration = FALSE)


###################################################
### code chunk number 18: RMassBank.Rnw:434-436
###################################################
w <- msmsWorkflow(w, mode="pH", steps=c(5:8), archivename = 
		"pH_narcotics")


###################################################
### code chunk number 19: RMassBank.Rnw:441-442 (eval = FALSE)
###################################################
## archiveResults(w, filename)


###################################################
### code chunk number 20: RMassBank.Rnw:468-472
###################################################
mb <- newMbWorkspace(w)
mb <- resetInfolists(mb)
mb <- loadInfolists(mb, system.file("infolists_incomplete",
		package="RMassBankData"))


###################################################
### code chunk number 21: RMassBank.Rnw:476-478 (eval = FALSE)
###################################################
## mb <- resetInfolists(mb)
## mb <- loadInfolists(mb, my_folder_with_csv_infolists_inside)


###################################################
### code chunk number 22: RMassBank.Rnw:482-483 (eval = FALSE)
###################################################
## mb <- addPeaks(mb, my_corrected_Failpeaks.csv)


###################################################
### code chunk number 23: RMassBank.Rnw:488-489
###################################################
mb <- mbWorkflow(mb, infolist_path="./Narcotics_infolist.csv")


###################################################
### code chunk number 24: RMassBank.Rnw:510-512 (eval = FALSE)
###################################################
## mb <- resetInfolists(mb)
## mb <- loadInfolists(mb, my_folder_with_csv_infolists_inside)


###################################################
### code chunk number 25: RMassBank.Rnw:518-520
###################################################
mb <- resetInfolists(mb)
mb <- loadInfolists(mb, system.file("infolists", package="RMassBankData"))


###################################################
### code chunk number 26: RMassBank.Rnw:526-527
###################################################
mb <- mbWorkflow(mb)


###################################################
### code chunk number 27: RMassBank.Rnw:564-565
###################################################
sessionInfo()
